<?php
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! class_exists( 'FILEBASE_OPTIONS' ) ) {
	/**
	 * FILEBASE_OPTIONS Class
	 *
	 * @since	1.0
	 */
	class FILEBASE_OPTIONS {


		/**
		 * Constructor
		 *
		 * @return	void
		 * @since	1.0
		 */
		function __construct() {
			$this->init();
		}

		public function init() {

			add_action( 'admin_menu', array( $this, 'admin_menu' ) );
			
			add_filter('bb_register_options', array( $this, 'options'), 10, 1 );

			if(is_admin()) {
				add_action( 'admin_enqueue_scripts', array( $this, 'adminEnqueueScripts' ) );
			}
			add_action( 'wp_enqueue_scripts', array( $this, 'enqueueScripts' ) );
        }

		public function adminEnqueueScripts() {
			if(isset($_GET['page']) && ($_GET['page'] == FILEBASE_SLUG || $_GET['page'] == FILEBASE_SLUG_SETTINGS )) {
				BestBug_Core_Options::adminEnqueueScripts();
			}
		}

		public function enqueueScripts() {
		
        }

		public function view() {
		
        }

		public function admin_menu() {
			$menu = array(
				'page_title' => esc_html('FileBase Settings', 'bestbug'),
				'menu_title' => esc_html('FileBase', 'bestbug'),
				'capability' => 'manage_options',
				'menu_slug' => FILEBASE_SLUG_SETTINGS,
				'icon' => 'dashicons-portfolio',
				'position' =>  76,
			);
			$this->page_title = $menu['page_title'];
			add_menu_page($menu['page_title'],
						$menu['menu_title'],
						$menu['capability'],
						$menu['menu_slug'],
						array(&$this, 'view'),
						$menu['icon'],
						$menu['position']
					);
        }
        
        public function options($options) {
			if( empty($options) ) {
				$options = array();
			}
			$prefix = FILEBASE_PREFIX;
			$options[] = array(
				'type' => 'options_fields',
				//'ajax_action' => FILEBASE_SAVE_SETTINS,
				'menu' => array(
					// add_submenu_page || add_menu_page
					'type' => 'add_submenu_page',
					'parent_slug' => FILEBASE_SLUG,
					'page_title' => esc_html('Settings', 'bestbug'),
					'menu_title' => esc_html('Settings', 'bestbug'),
					'capability' => 'manage_options',
					'menu_slug' => FILEBASE_SLUG_SETTINGS,
				),
				'fields' => array(
					// tabs
					array(
						'type'       => 'tab',
						'param_name' => $prefix . 'tab',
						'value'      => array(
						  'product_license' => esc_html__( 'Product License', 'bestbug' ),
						),
						'std' => 'product_license',
						'description' => esc_html__('', 'bestbug'),
					),
					array(
						'type'       => 'password',
						'heading'    => esc_html__( 'Purchase code', 'bestbug' ),
						'param_name' => $prefix . 'purchase_code',
						'value'      => '',
						'description' => '<p><a target="_blank" href="https://1.envato.market/24335198">Get it now</a> | <a target="_blank" href="https://bestbug.ticksy.com/article/17080/">How to get Purchase Code?</a></p>',
						'tab' => array(
							'element' =>  $prefix . 'tab',
							'value' => array('product_license')
						),
					),
					array(
						'type'       => 'text',
						'heading'    => '',
						'param_name' => $prefix . 'verify_now',
						'value'      => '<button type="button" class="button primary bb-vertify-button" data-slug="bbfilebase" data-target="#'.$prefix .'purchase_code">Vertify Now</button>',
						'description' => 'Enter purchase code and press "Vertify Now" button',
						'tab' => array(
							'element' =>  $prefix . 'tab',
							'value' => array('product_license')
						),
					),
				),
			);
			
			return $options;
        }
        
    }
	
	new FILEBASE_OPTIONS();
}

