<?php
/*
Plugin Name: FileBase - WordPress Media Library Folders
Description: Manage thousands media files in WordPress media library easily using the drag&drop interface.
Author: پرشین اسکریپت
Version: 2.0.5
Author URI: www.persianscript.ir
Text Domain: bestbug
Domain Path: /languages
*/

if ( ! defined( 'WPINC' ) ) {
	die();
}

defined( 'FILEBASE_PLUGIN_NAME' ) or define( 'FILEBASE_PLUGIN_NAME', 'File Base' ) ;
defined( 'FILEBASE_VERSION' ) or define('FILEBASE_VERSION', '2.0.5') ;
defined( 'FILEBASE__FILE__' ) or define( 'FILEBASE__FILE__', __FILE__ );
defined( 'FILEBASE_TAX_FOLDER' ) or define( 'FILEBASE_TAX_FOLDER', 'filebase_folder' );
defined( 'FILEBASE_PATH' ) or define( 'FILEBASE_PATH', plugin_dir_path( __FILE__ ) );
defined( 'FILEBASE_TEXT_DOMAIN' ) or define( 'FILEBASE_TEXT_DOMAIN', 'bestbug');
defined( 'FILEBASE_PLUGIN_BASE' ) or define( 'FILEBASE_PLUGIN_BASE', plugin_basename( __FILE__ ) );
defined( 'FILEBASE_URL' ) or define('FILEBASE_URL', plugins_url( '/', __FILE__ )) ;

defined( 'FILEBASE_PREFIX' ) or define('FILEBASE_PREFIX', 'filebase_');
// PAGE SLUG
defined( 'FILEBASE_SLUG' ) or define('FILEBASE_SLUG', 'filebase_settings');
defined( 'FILEBASE_SLUG_SETTINGS' ) or define('FILEBASE_SLUG_SETTINGS', 'filebase_settings');
defined( 'FILEBASE_ABOUT_SLUG' ) or define('FILEBASE_ABOUT_SLUG', 'filebase_about');

if ( ! class_exists( 'FileBase_Class' ) ) {
	/**
	 * FileBase_Class Class
	 *
	 * @since	1.0
	 */

	class FileBase_Class {
		
		/**
		 * Constructor
		 *
		 * @return	void
		 * @since	1.0
		 */
		function __construct() {
			// Load core
			if(!class_exists('BESTBUG_CORE_CLASS')) {
				include_once 'bestbugcore/index.php';
			}
			BESTBUG_CORE_CLASS::support('options');
			
			if(is_admin()) {
				include_once 'includes/index.php';
			}
			
			add_action( 'init', array( $this, 'init' ) );
		}

		public function init() {
			// Load enqueueScripts
			if(is_admin()) {
				add_action( 'admin_enqueue_scripts', array( $this, 'adminEnqueueScripts' ) );
			}
			add_action( 'wp_enqueue_scripts', array( $this, 'enqueueScripts' ) );
			if (defined('ELEMENTOR_VERSION')) {
				add_action('elementor/editor/before_enqueue_scripts',array( $this, 'adminEnqueueScripts' ));
			}
		}

		public function adminEnqueueScripts() {
			BestBug_Core_Class::adminEnqueueScripts();
			// css
			wp_enqueue_style('filebase-main', FILEBASE_URL . '/assets/css/style.css', array(),FILEBASE_VERSION, 'all');
			wp_enqueue_style('antd-message', FILEBASE_URL . '/assets/includes/antd-message/style.css', array(), null, 'all');
			wp_enqueue_style('perfect-scrollbar', FILEBASE_URL . '/assets/includes/perfect-scrollbar/perfect-scrollbar.css', array(), null, 'all');
			wp_enqueue_style('filebase-icon', FILEBASE_URL . '/assets/includes/filebase-icon/style.css', array(), null, 'all');
			wp_enqueue_style('sweetalert', FILEBASE_URL . '/assets/includes/sweet-alert/sweetalert.css', array(), null, 'all');
			wp_enqueue_style('font-awesome', FILEBASE_URL . '/assets/includes/font-fa/css/font-awesome.min.css', array(), null, 'all');
			wp_enqueue_style('bootstrap', FILEBASE_URL . '/assets/includes/bootstrap/css/bootstrap.min.css', array(), null, 'all');
			wp_enqueue_style('contextMenu', FILEBASE_URL . '/assets/includes/contextMenu/jquery.contextMenu.min.css', array(), null, 'all');
			wp_enqueue_script( 'jquery' );
			wp_enqueue_script('jquery-ui-core');
			wp_enqueue_script('jquery-ui-sortable');
			wp_enqueue_script('jquery-ui-draggable');
			wp_enqueue_script('jquery-ui-droppable');
			wp_enqueue_script('jquery-ui-selectable');

			wp_enqueue_script( 'filebase-topbar', FILEBASE_URL . 'assets/js/hmh-topbar.js', array(), FILEBASE_VERSION, true );
			$getTerms = get_terms(FILEBASE_TAX_FOLDER, array(
		        'hide_empty' => false,
		    ));
			$array_list_term = array(array(
					'term_id' =>  -1,
					'term_name' => 'Uncategorized',
					));
		    foreach ($getTerms as $key => $value) {
				array_push($array_list_term,array(
					'term_id' =>  $value->term_id,
					'term_name' => $value->name,
					)
				);			
		    }
		    $array_hmh = array(
				'folder' => array(
					'list_title' => 'All',
					'term_list' => $array_list_term,
				),
			);
			wp_localize_script( 'filebase-topbar', 'hmh_taxonomies', $array_hmh );
			wp_enqueue_script( 'antd-message', FILEBASE_URL . '/assets/includes/antd-message/index.js', array(), FILEBASE_VERSION, true );
			wp_enqueue_script( 'filebase-load-folder', FILEBASE_URL . '/assets/js/load-folder.js', array(), FILEBASE_VERSION, true );
			
			// wp_enqueue_script( 'jquery.ui.sortable-animation', FILEBASE_URL . '/assets/includes/jquery.ui.sortable-animation.js', array(), FILEBASE_VERSION, true );
			wp_enqueue_script( 'nestedSortable', FILEBASE_URL . '/assets/includes/nestedSortable.js', array(), FILEBASE_VERSION, true );

			wp_enqueue_script( 'popper', FILEBASE_URL . '/assets/includes/tippy/popper.min.js', array(), FILEBASE_VERSION, true );
			wp_enqueue_script( 'tippy', FILEBASE_URL . '/assets/includes/tippy/tippy-bundle.iife.min.js', array(), FILEBASE_VERSION, true );

			wp_enqueue_script( 'filebase-main', FILEBASE_URL . '/assets/js/main.js', array(), FILEBASE_VERSION, true );
			wp_enqueue_script( 'filebase-folder', FILEBASE_URL . '/assets/js/folder.js', array(), FILEBASE_VERSION, true );
			wp_enqueue_script( 'filebase-load-popup', FILEBASE_URL . '/assets/js/load-popup.js', array(), FILEBASE_VERSION, true );
			
			wp_enqueue_script( 'filebase-media-new-php', FILEBASE_URL . '/assets/js/media-new-php.js', array(), FILEBASE_VERSION, true );
			wp_enqueue_script( 'filebase-hook-post-add-media', FILEBASE_URL . '/assets/js/hook-post-add-media.js', array('jquery'), FILEBASE_VERSION, true );
			wp_enqueue_script('sweetalert2', FILEBASE_URL . '/assets/includes/sweet-alert/sweetalert2.all.js', array(), null, true );
			wp_enqueue_script('jquery-resizable', FILEBASE_URL . '/assets/includes/rick-strahl/jquery-resizable.js', array(), null, true );
			wp_enqueue_script('dknotus-tour', FILEBASE_URL . '/assets/includes/tour/dknotus-tour.min.js', array(), null, true );
			wp_enqueue_script('contextMenu', FILEBASE_URL . '/assets/includes/contextMenu/jquery.contextMenu.min.js', array(), null, true );
			wp_enqueue_script('perfect-scrollbar', FILEBASE_URL . '/assets/includes/perfect-scrollbar/perfect-scrollbar.min.js', array(), null, true );

			wp_enqueue_script( 'jquery-cookie', BESTBUG_CORE_URL . '/assets/js/jquery.cookie.js', array( 'jquery' ), BESTBUG_CORE_VERSION, true );
		}

		public function enqueueScripts() {
			
		}

		function wpdocs_load_textdomain() {
			load_plugin_textdomain( 'wpmp_ftel_textdomain', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' ); 
		}
	}
	new FileBase_Class();

}
